let game;
let gameOptions = {
    gameScale: 0.1,
    ballRadius: 25
}
window.onload = function() {
    let gameConfig = {
        type: Phaser.AUTO,
        scale: {
            mode: Phaser.Scale.FIT,
            autoCenter: Phaser.Scale.CENTER_BOTH,
            parent: "thegame",
            width: 600,
            height: 800
        },
        physics: {
            default: "arcade"
        },
        scene: playGame
    }
    game = new Phaser.Game(gameConfig);
    window.focus();
}
class playGame extends Phaser.Scene{
    constructor(){
        super({
            pack: {
                files: [
                    {
                        type: "script",
                        key: "threeJS",
                        url: "three.min.js"
                    },
                    {
                        type: "script",
                        key: "Phaser3D",
                        url: "Phaser3D.js"
                    }
                ]
            }
        });
    }
    preload(){
        this.load.image("redball", "redball.png");
        this.load.image("blueball", "blueball.png");
        this.load.script("OrbitControls", "OrbitControls.js");
    }
    create(){

        this.phaser3d = new Phaser3D(this, {
            fov: 45,
            near: 1,
            far: 1000,
            x: 0,
            y: 95,
            z: 0
        });

        this.phaser3d.camera.lookAt(0, 0, 0);

        this.phaser3d.enableShadows();
        this.phaser3d.enableGamma();

        this.phaser3d.add.ambientLight({
            color: 0xffffff,
            intensity: 0.1
        });

        new THREE.OrbitControls(this.phaser3d.camera, this.scale.parent);

        let spotlight = this.phaser3d.add.spotLight({
            intensity: 0.5,
            angle: 0.4,
            decay: 0.1,
            distance: 250,
            x: 0,
            y: 220,
            z: 0
        });

        this.addThreeBound(10, game.config.height + 20, game.config.width / 2 + 5, 0);
        this.addThreeBound(10, game.config.height + 20, - game.config.width / 2 - 5, 0);
        this.addThreeBound(game.config.width, 10, 0, game.config.height / 2 + 5);
        this.addThreeBound(game.config.width, 10, 0, - game.config.height / 2 - 5);

        let ground = this.phaser3d.add.box({
            width: (game.config.width + 20) * gameOptions.gameScale,
            height: 10 * gameOptions.gameScale,
            depth: (game.config.height + 20) * gameOptions.gameScale,
            color: 0xffff00,
            x: 0,
            y: -5 * gameOptions.gameScale,
            z: 0,
            material: {
                dithering: true,
                phong: true
            }
        });

        this.redThreeBall = this.addThreeBall(0xff0000);
        this.blueThreeBall = this.addThreeBall(0x0000ff);

        this.phaser3d.castShadow(this.redThreeBall, this.blueThreeBall);
        this.phaser3d.receiveShadow(ground);

        this.phaser3d.setShadow(spotlight, 512, 512);

        this.redBall = this.addArcadeBall("redball");
        this.blueBall = this.addArcadeBall("blueball");
        this.physics.add.collider(this.redBall, this.blueBall);
    }

    addThreeBound(width, depth, posX, posZ){
        this.phaser3d.add.box({
            width: width * gameOptions.gameScale,
            height: gameOptions.ballRadius * gameOptions.gameScale,
            depth: depth * gameOptions.gameScale,
            color: 0x00ff00,
            x: posX * gameOptions.gameScale,
            y: gameOptions.ballRadius / 2  * gameOptions.gameScale,
            z: posZ * gameOptions.gameScale,
            material: {
                dithering: true,
                phong: true
            }
        });
    }

    addThreeBall(color){
        return this.phaser3d.add.sphere({
            radius: gameOptions.ballRadius * gameOptions.gameScale,
            widthSegments: 32,
            heightSegments: 32,
            color: color,
            x: 0,
            y: 25 * gameOptions.gameScale,
            z: 0,
            material: {
                dithering: true,
                phong: true
            }
        });
    }

    addArcadeBall(key){
        let posX = Phaser.Math.Between(gameOptions.ballRadius, game.config.width - gameOptions.ballRadius);
        let posY = Phaser.Math.Between(gameOptions.ballRadius, game.config.height - gameOptions.ballRadius);
        let ball = this.physics.add.sprite(posX, posY, key);
        ball.setCircle(gameOptions.ballRadius);
        ball.setCollideWorldBounds(true);
        ball.setBounce(1);
        let angle = Phaser.Math.RND.rotation();
        ball.setVelocity(400 * Math.cos(angle), 400 * Math.sin(angle));
        return ball
    }

    update(){
        this.redThreeBall.position.x = (this.redBall.x - game.config.width / 2) * gameOptions.gameScale;
        this.redThreeBall.position.z = (this.redBall.y - game.config.height / 2) * gameOptions.gameScale;
        this.blueThreeBall.position.x = (this.blueBall.x - game.config.width / 2) * gameOptions.gameScale;
        this.blueThreeBall.position.z = (this.blueBall.y - game.config.height / 2) * gameOptions.gameScale;
    }
}
